@@ -1222,73 +1222,98 @@
         return Stateful;
     }
 
-    const MessageType = {
-        UI_GET_DATA: "ui-get-data",
-        UI_SUBSCRIBE_TO_CHANGES: "ui-subscribe-to-changes",
-        UI_UNSUBSCRIBE_FROM_CHANGES: "ui-unsubscribe-from-changes",
-        UI_CHANGE_SETTINGS: "ui-change-settings",
-        UI_SET_THEME: "ui-set-theme",
-        UI_SET_SHORTCUT: "ui-set-shortcut",
-        UI_TOGGLE_ACTIVE_TAB: "ui-toggle-active-tab",
-        UI_MARK_NEWS_AS_READ: "ui-mark-news-as-read",
-        UI_MARK_NEWS_AS_DISPLAYED: "ui-mark-news-as-displayed",
-        UI_LOAD_CONFIG: "ui-load-config",
-        UI_APPLY_DEV_DYNAMIC_THEME_FIXES: "ui-apply-dev-dynamic-theme-fixes",
-        UI_RESET_DEV_DYNAMIC_THEME_FIXES: "ui-reset-dev-dynamic-theme-fixes",
-        UI_APPLY_DEV_INVERSION_FIXES: "ui-apply-dev-inversion-fixes",
-        UI_RESET_DEV_INVERSION_FIXES: "ui-reset-dev-inversion-fixes",
-        UI_APPLY_DEV_STATIC_THEMES: "ui-apply-dev-static-themes",
-        UI_RESET_DEV_STATIC_THEMES: "ui-reset-dev-static-themes",
-        UI_SAVE_FILE: "ui-save-file",
-        UI_REQUEST_EXPORT_CSS: "ui-request-export-css",
-        BG_CHANGES: "bg-changes",
-        BG_ADD_CSS_FILTER: "bg-add-css-filter",
-        BG_ADD_STATIC_THEME: "bg-add-static-theme",
-        BG_ADD_SVG_FILTER: "bg-add-svg-filter",
-        BG_ADD_DYNAMIC_THEME: "bg-add-dynamic-theme",
-        BG_EXPORT_CSS: "bg-export-css",
-        BG_UNSUPPORTED_SENDER: "bg-unsupported-sender",
-        BG_CLEAN_UP: "bg-clean-up",
-        BG_RELOAD: "bg-reload",
-        BG_FETCH_RESPONSE: "bg-fetch-response",
-        BG_UI_UPDATE: "bg-ui-update",
-        BG_CSS_UPDATE: "bg-css-update",
-        CS_COLOR_SCHEME_CHANGE: "cs-color-scheme-change",
-        CS_FRAME_CONNECT: "cs-frame-connect",
-        CS_FRAME_FORGET: "cs-frame-forget",
-        CS_FRAME_FREEZE: "cs-frame-freeze",
-        CS_FRAME_RESUME: "cs-frame-resume",
-        CS_EXPORT_CSS_RESPONSE: "cs-export-css-response",
-        CS_FETCH: "cs-fetch",
-        CS_DARK_THEME_DETECTED: "cs-dark-theme-detected",
-        CS_DARK_THEME_NOT_DETECTED: "cs-dark-theme-not-detected"
-    };
+    var MessageType;
+    (function (MessageType) {
+        MessageType["UI_GET_DATA"] = "ui-get-data";
+        MessageType["UI_SUBSCRIBE_TO_CHANGES"] = "ui-subscribe-to-changes";
+        MessageType["UI_UNSUBSCRIBE_FROM_CHANGES"] =
+            "ui-unsubscribe-from-changes";
+        MessageType["UI_CHANGE_SETTINGS"] = "ui-change-settings";
+        MessageType["UI_SET_THEME"] = "ui-set-theme";
+        MessageType["UI_SET_SHORTCUT"] = "ui-set-shortcut";
+        MessageType["UI_TOGGLE_ACTIVE_TAB"] = "ui-toggle-active-tab";
+        MessageType["UI_MARK_NEWS_AS_READ"] = "ui-mark-news-as-read";
+        MessageType["UI_MARK_NEWS_AS_DISPLAYED"] = "ui-mark-news-as-displayed";
+        MessageType["UI_LOAD_CONFIG"] = "ui-load-config";
+        MessageType["UI_APPLY_DEV_DYNAMIC_THEME_FIXES"] =
+            "ui-apply-dev-dynamic-theme-fixes";
+        MessageType["UI_RESET_DEV_DYNAMIC_THEME_FIXES"] =
+            "ui-reset-dev-dynamic-theme-fixes";
+        MessageType["UI_APPLY_DEV_INVERSION_FIXES"] =
+            "ui-apply-dev-inversion-fixes";
+        MessageType["UI_RESET_DEV_INVERSION_FIXES"] =
+            "ui-reset-dev-inversion-fixes";
+        MessageType["UI_APPLY_DEV_STATIC_THEMES"] =
+            "ui-apply-dev-static-themes";
+        MessageType["UI_RESET_DEV_STATIC_THEMES"] =
+            "ui-reset-dev-static-themes";
+        MessageType["UI_SAVE_FILE"] = "ui-save-file";
+        MessageType["UI_REQUEST_EXPORT_CSS"] = "ui-request-export-css";
+        MessageType["UI_COLOR_SCHEME_CHANGE"] = "ui-color-scheme-change";
+        MessageType["BG_CHANGES"] = "bg-changes";
+        MessageType["BG_ADD_CSS_FILTER"] = "bg-add-css-filter";
+        MessageType["BG_ADD_STATIC_THEME"] = "bg-add-static-theme";
+        MessageType["BG_ADD_SVG_FILTER"] = "bg-add-svg-filter";
+        MessageType["BG_ADD_DYNAMIC_THEME"] = "bg-add-dynamic-theme";
+        MessageType["BG_EXPORT_CSS"] = "bg-export-css";
+        MessageType["BG_UNSUPPORTED_SENDER"] = "bg-unsupported-sender";
+        MessageType["BG_CLEAN_UP"] = "bg-clean-up";
+        MessageType["BG_RELOAD"] = "bg-reload";
+        MessageType["BG_FETCH_RESPONSE"] = "bg-fetch-response";
+        MessageType["BG_UI_UPDATE"] = "bg-ui-update";
+        MessageType["BG_CSS_UPDATE"] = "bg-css-update";
+        MessageType["CS_COLOR_SCHEME_CHANGE"] = "cs-color-scheme-change";
+        MessageType["CS_FRAME_CONNECT"] = "cs-frame-connect";
+        MessageType["CS_FRAME_FORGET"] = "cs-frame-forget";
+        MessageType["CS_FRAME_FREEZE"] = "cs-frame-freeze";
+        MessageType["CS_FRAME_RESUME"] = "cs-frame-resume";
+        MessageType["CS_EXPORT_CSS_RESPONSE"] = "cs-export-css-response";
+        MessageType["CS_FETCH"] = "cs-fetch";
+        MessageType["CS_DARK_THEME_DETECTED"] = "cs-dark-theme-detected";
+        MessageType["CS_DARK_THEME_NOT_DETECTED"] =
+            "cs-dark-theme-not-detected";
+        MessageType["CS_LOG"] = "cs-log";
+    })(MessageType || (MessageType = {}));
 
-    const userAgent =
-        typeof navigator === "undefined"
-            ? "some useragent"
-            : navigator.userAgent.toLowerCase();
-    const platform =
-        typeof navigator === "undefined"
-            ? "some platform"
-            : navigator.platform.toLowerCase();
-    const isChromium =
-        userAgent.includes("chrome") || userAgent.includes("chromium");
-    const isThunderbird = userAgent.includes("thunderbird");
-    const isFirefox =
-        userAgent.includes("firefox") ||
-        userAgent.includes("librewolf") ||
-        isThunderbird;
+    const isNavigatorDefined = typeof navigator !== "undefined";
+    const userAgent = isNavigatorDefined
+        ? navigator.userAgentData &&
+          Array.isArray(navigator.userAgentData.brands)
+            ? navigator.userAgentData.brands
+                  .map(
+                      (brand) => `${brand.brand.toLowerCase()} ${brand.version}`
+                  )
+                  .join(" ")
+            : navigator.userAgent.toLowerCase()
+        : "some useragent";
+    const platform = isNavigatorDefined
+        ? navigator.userAgentData &&
+          typeof navigator.userAgentData.platform === "string"
+            ? navigator.userAgentData.platform.toLowerCase()
+            : navigator.platform.toLowerCase()
+        : "some platform";
     userAgent.includes("vivaldi");
     userAgent.includes("yabrowser");
     userAgent.includes("opr") || userAgent.includes("opera");
     userAgent.includes("edg");
-    userAgent.includes("safari") && !isChromium;
     platform.startsWith("win");
     platform.startsWith("mac");
-    userAgent.includes("mobile");
+    isNavigatorDefined && navigator.userAgentData
+        ? navigator.userAgentData.mobile
+        : userAgent.includes("mobile");
+    (isNavigatorDefined &&
+        navigator.userAgentData &&
+        ["Linux", "Android"].includes(navigator.userAgentData.platform)) ||
+        platform.startsWith("linux");
     (() => {
-        const m = userAgent.match(/chrom[e|ium]\/([^ ]+)/);
+        const m = userAgent.match(/chrom(?:e|ium)(?:\/| )([^ ]+)/);
+        if (m && m[1]) {
+            return m[1];
+        }
+        return "";
+    })();
+    (() => {
+        const m = userAgent.match(/(?:firefox|librewolf)(?:\/| )([^ ]+)/);
         if (m && m[1]) {
             return m[1];
         }
@@ -1302,10 +1327,6 @@
             return false;
         }
     })();
-    globalThis.chrome &&
-        globalThis.chrome.runtime &&
-        globalThis.chrome.runtime.getManifest &&
-        globalThis.chrome.runtime.getManifest().manifest_version === 3;
     (() => {
         if (typeof document === "undefined") {
             return false;
@@ -1415,6 +1436,115 @@
         );
     }
 
+    function evalMath(expression) {
+        const rpnStack = [];
+        const workingStack = [];
+        let lastToken;
+        for (let i = 0, len = expression.length; i < len; i++) {
+            const token = expression[i];
+            if (!token || token === " ") {
+                continue;
+            }
+            if (operators.has(token)) {
+                const op = operators.get(token);
+                while (workingStack.length) {
+                    const currentOp = operators.get(workingStack[0]);
+                    if (!currentOp) {
+                        break;
+                    }
+                    if (op.lessOrEqualThan(currentOp)) {
+                        rpnStack.push(workingStack.shift());
+                    } else {
+                        break;
+                    }
+                }
+                workingStack.unshift(token);
+            } else if (!lastToken || operators.has(lastToken)) {
+                rpnStack.push(token);
+            } else {
+                rpnStack[rpnStack.length - 1] += token;
+            }
+            lastToken = token;
+        }
+        rpnStack.push(...workingStack);
+        const stack = [];
+        for (let i = 0, len = rpnStack.length; i < len; i++) {
+            const op = operators.get(rpnStack[i]);
+            if (op) {
+                const args = stack.splice(0, 2);
+                stack.push(op.exec(args[1], args[0]));
+            } else {
+                stack.unshift(parseFloat(rpnStack[i]));
+            }
+        }
+        return stack[0];
+    }
+    class Operator {
+        constructor(precedence, method) {
+            this.precendce = precedence;
+            this.execMethod = method;
+        }
+        exec(left, right) {
+            return this.execMethod(left, right);
+        }
+        lessOrEqualThan(op) {
+            return this.precendce <= op.precendce;
+        }
+    }
+    const operators = new Map([
+        ["+", new Operator(1, (left, right) => left + right)],
+        ["-", new Operator(1, (left, right) => left - right)],
+        ["*", new Operator(2, (left, right) => left * right)],
+        ["/", new Operator(2, (left, right) => left / right)]
+    ]);
+
+    function getParenthesesRange(input, searchStartIndex = 0) {
+        const length = input.length;
+        let depth = 0;
+        let firstOpenIndex = -1;
+        for (let i = searchStartIndex; i < length; i++) {
+            if (depth === 0) {
+                const openIndex = input.indexOf("(", i);
+                if (openIndex < 0) {
+                    break;
+                }
+                firstOpenIndex = openIndex;
+                depth++;
+                i = openIndex;
+            } else {
+                const closingIndex = input.indexOf(")", i);
+                if (closingIndex < 0) {
+                    break;
+                }
+                const openIndex = input.indexOf("(", i);
+                if (openIndex < 0 || closingIndex < openIndex) {
+                    depth--;
+                    if (depth === 0) {
+                        return {start: firstOpenIndex, end: closingIndex + 1};
+                    }
+                    i = closingIndex;
+                } else {
+                    depth++;
+                    i = openIndex;
+                }
+            }
+        }
+        return null;
+    }
+
+    const rgbaParseCache = new Map();
+    function parseColorWithCache($color) {
+        $color = $color.trim();
+        if (rgbaParseCache.has($color)) {
+            return rgbaParseCache.get($color);
+        }
+        if ($color.includes("calc(")) {
+            $color = lowerCalcExpression($color);
+        }
+        const color = parse($color);
+        color && rgbaParseCache.set($color, color);
+        return color;
+    }
     function hslToRGB({h, s, l, a = 1}) {
         if (s === 0) {
             const [r, b, g] = [l, l, l].map((x) => Math.round(x * 255));
@@ -1520,7 +1650,7 @@
         if ($color === "transparent") {
             return {r: 0, g: 0, b: 0, a: 0};
         }
-        throw new Error(`Unable to parse ${$color}`);
+        return null;
     }
     function getNumbers($color) {
         const numbers = [];
@@ -1602,7 +1732,7 @@
                 return {r, g, b, a};
             }
         }
-        throw new Error(`Unable to parse ${$hex}`);
+        return null;
     }
     function getColorByName($color) {
         const n = knownColors.get($color);
@@ -1622,6 +1752,29 @@
             a: 1
         };
     }
+    function lowerCalcExpression(color) {
+        let searchIndex = 0;
+        const replaceBetweenIndices = (start, end, replacement) => {
+            color =
+                color.substring(0, start) + replacement + color.substring(end);
+        };
+        while ((searchIndex = color.indexOf("calc(")) !== -1) {
+            const range = getParenthesesRange(color, searchIndex);
+            if (!range) {
+                break;
+            }
+            let slice = color.slice(range.start + 1, range.end - 1);
+            const includesPercentage = slice.includes("%");
+            slice = slice.split("%").join("");
+            const output = Math.round(evalMath(slice));
+            replaceBetweenIndices(
+                range.start - 4,
+                range.end,
+                output + (includesPercentage ? "%" : "")
+            );
+        }
+        return color;
+    }
     const knownColors = new Map(
         Object.entries({
             aliceblue: 0xf0f8ff,
@@ -1811,9 +1964,10 @@
     function TextBox(props) {
         const cls = mergeClass("textbox", props.class);
         const attrs = omitAttrs(["class", "type"], props);
+        const type = props.type || "text";
         return m$1("input", {
             class: cls,
-            type: "text",
+            type: type,
             spellcheck: "false",
             ...attrs
         });
@@ -1914,7 +2068,7 @@
             props.color !== prevColor && props.color !== prevActiveColor;
         let activeHSB;
         if (didColorChange) {
-            const rgb = parse(props.color);
+            const rgb = parseColorWithCache(props.color);
             activeHSB = rgbToHSB(rgb);
             store.activeHSB = activeHSB;
         } else {
@@ -1925,7 +2079,8 @@
                 return;
             }
             const hue = activeHSB.h;
-            const prevHue = prevColor && rgbToHSB(parse(prevColor)).h;
+            const prevHue =
+                prevColor && rgbToHSB(parseColorWithCache(prevColor)).h;
             if (store.wasPrevHidden || hue !== prevHue) {
                 renderSB(hue, canvas);
             }
@@ -2047,12 +2202,7 @@
     }
 
     function isValidColor(color) {
-        try {
-            parse(color);
-            return true;
-        } catch (err) {
-            return false;
-        }
+        return Boolean(parseColorWithCache(color));
     }
     const colorPickerFocuses = new WeakMap();
     function focusColorPicker(node) {
@@ -2235,55 +2385,40 @@
                         },
                         "OK"
                     ),
-                    m$1(
-                        Button,
-                        {
-                            class: "message-box__button message-box__button-cancel",
-                            onclick: props.onCancel
-                        },
-                        "Cancel"
-                    )
+                    props.hideCancel
+                        ? null
+                        : m$1(
+                              Button,
+                              {
+                                  class: "message-box__button message-box__button-cancel",
+                                  onclick: props.onCancel
+                              },
+                              "Cancel"
+                          )
                 )
             )
         );
     }
 
-    function getUILanguage() {
-        let code;
-        if (
-            "i18n" in chrome &&
-            "getUILanguage" in chrome.i18n &&
-            typeof chrome.i18n.getUILanguage === "function"
-        ) {
-            code = chrome.i18n.getUILanguage();
-        } else {
-            code = navigator.language.split("-")[0];
-        }
-        if (code.endsWith("-mac")) {
-            return code.substring(0, code.length - 4);
-        }
-        return code;
-    }
-
-    new Date().toLocaleTimeString(getUILanguage()).endsWith("M");
-
-    var ThemeEngines = {
-        cssFilter: "cssFilter",
-        svgFilter: "svgFilter",
-        staticTheme: "staticTheme",
-        dynamicTheme: "dynamicTheme"
-    };
+    var ThemeEngine;
+    (function (ThemeEngine) {
+        ThemeEngine["cssFilter"] = "cssFilter";
+        ThemeEngine["svgFilter"] = "svgFilter";
+        ThemeEngine["staticTheme"] = "staticTheme";
+        ThemeEngine["dynamicTheme"] = "dynamicTheme";
+    })(ThemeEngine || (ThemeEngine = {}));
 
     const DEVTOOLS_DOCS_URL =
-        "https://github.com/darkreader/darkreader/blob/master/CONTRIBUTING.md";
+        "https://github.com/darkreader/darkreader/blob/main/CONTRIBUTING.md";
 
+    const simpleIPV6Regex = /\[[0-9:a-zA-Z]*?\]/;
     function isIPV6(url) {
-        const openingBracketIndex = url.indexOf("[");
-        if (openingBracketIndex < 0) {
+        const openingBracketIndex = simpleIPV6Regex.exec(url);
+        if (!openingBracketIndex) {
             return false;
         }
         const queryIndex = url.indexOf("?");
-        if (queryIndex >= 0 && openingBracketIndex > queryIndex) {
+        if (queryIndex >= 0 && openingBracketIndex.index > queryIndex) {
             return false;
         }
         return true;
@@ -2318,6 +2453,7 @@
         urlTemplate = urlTemplate.trim();
         const exactBeginning = urlTemplate[0] === "^";
         const exactEnding = urlTemplate[urlTemplate.length - 1] === "$";
+        const hasLastSlash = /\/\$?$/.test(urlTemplate);
         urlTemplate = urlTemplate
             .replace(/^\^/, "")
             .replace(/\$$/, "")
@@ -2350,7 +2486,9 @@
             result += afterSlash.replace("/", "\\/");
             result += ")";
         }
-        result += exactEnding ? "(\\/?(\\?[^/]*?)?)$" : "(\\/?.*?)$";
+        result += exactEnding
+            ? "(\\/?(\\?[^/]*?)?)$"
+            : `(\\/${hasLastSlash ? "" : "?"}.*?)$`;
         return new RegExp(result, "i");
     }
 
@@ -2388,11 +2526,13 @@
             }
             if (
                 config.mode != null &&
-                props.data.settings.automation &&
-                props.data.settings.automationBehaviour === "Scheme"
+                props.data.settings.automation.behavior === "Scheme"
             ) {
                 props.actions.changeSettings({
-                    automation: ""
+                    automation: {
+                        ...props.data.settings.automation,
+                        ...{enabled: false}
+                    }
                 });
             }
         }
@@ -2411,15 +2551,15 @@
             : "Preview new design";
         const {theme} = getCurrentThemePreset({data, actions});
         const wrapper =
-            theme.engine === ThemeEngines.staticTheme
+            theme.engine === ThemeEngine.staticTheme
                 ? {
                       header: "Static Theme Editor",
                       fixesText: data.devtools.staticThemesText,
                       apply: (text) => actions.applyDevStaticThemes(text),
                       reset: () => actions.resetDevStaticThemes()
                   }
-                : theme.engine === ThemeEngines.cssFilter ||
-                  theme.engine === ThemeEngines.svgFilter
+                : theme.engine === ThemeEngine.cssFilter ||
+                  theme.engine === ThemeEngine.svgFilter
                 ? {
                       header: "Inversion Fix Editor",
                       fixesText: data.devtools.filterFixesText,
@@ -2441,16 +2581,7 @@
                 if (e.key === "Tab") {
                     e.preventDefault();
                     const indent = " ".repeat(4);
-                    if (isFirefox) {
-                        const start = node.selectionStart;
-                        const end = node.selectionEnd;
-                        const before = node.value.substring(0, start);
-                        const after = node.value.substring(end);
-                        node.focus();
-                        node.value = `${before}${indent}${after}`;
-                        const cursorPos = start + indent.length;
-                        node.setSelectionRange(cursorPos, cursorPos);
-                    } else {
+                    {
                         document.execCommand("insertText", false, indent);
                     }
                 }
@@ -2593,11 +2724,6 @@
             });
         }
         async getData() {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_GET_DATA
-                );
-            }
             return await this.sendRequest(MessageType.UI_GET_DATA);
         }
         subscribeToChanges(callback) {
@@ -2652,12 +2778,6 @@
             });
         }
         async applyDevDynamicThemeFixes(text) {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_APPLY_DEV_DYNAMIC_THEME_FIXES,
-                    text
-                );
-            }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_DYNAMIC_THEME_FIXES,
                 text
@@ -2669,12 +2789,6 @@
             });
         }
         async applyDevInversionFixes(text) {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_APPLY_DEV_INVERSION_FIXES,
-                    text
-                );
-            }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_INVERSION_FIXES,
                 text
@@ -2686,12 +2800,6 @@
             });
         }
         async applyDevStaticThemes(text) {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_APPLY_DEV_STATIC_THEMES,
-                    text
-                );
-            }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_STATIC_THEMES,
                 text
