@@ -1242,11 +1242,6 @@
             ? navigator.userAgentData.platform.toLowerCase()
             : navigator.platform.toLowerCase()
         : "some platform";
-    const isThunderbird = userAgent.includes("thunderbird");
-    const isFirefox =
-        userAgent.includes("firefox") ||
-        userAgent.includes("librewolf") ||
-        isThunderbird;
     userAgent.includes("vivaldi");
     userAgent.includes("yabrowser");
     userAgent.includes("opr") || userAgent.includes("opera");
@@ -1256,6 +1251,10 @@
     isNavigatorDefined && navigator.userAgentData
         ? navigator.userAgentData.mobile
         : userAgent.includes("mobile");
+    (isNavigatorDefined &&
+        navigator.userAgentData &&
+        ["Linux", "Android"].includes(navigator.userAgentData.platform)) ||
+        platform.startsWith("linux");
     (() => {
         const m = userAgent.match(/chrom(?:e|ium)(?:\/| )([^ ]+)/);
         if (m && m[1]) {
@@ -2336,26 +2335,29 @@
                         },
                         "OK"
                     ),
-                    m$1(
-                        Button,
-                        {
-                            class: "message-box__button message-box__button-cancel",
-                            onclick: props.onCancel
-                        },
-                        "Cancel"
-                    )
+                    props.hideCancel
+                        ? null
+                        : m$1(
+                              Button,
+                              {
+                                  class: "message-box__button message-box__button-cancel",
+                                  onclick: props.onCancel
+                              },
+                              "Cancel"
+                          )
                 )
             )
         );
     }
 
+    const simpleIPV6Regex = /\[[0-9:a-zA-Z]*?\]/;
     function isIPV6(url) {
-        const openingBracketIndex = url.indexOf("[");
-        if (openingBracketIndex < 0) {
+        const openingBracketIndex = simpleIPV6Regex.exec(url);
+        if (!openingBracketIndex) {
             return false;
         }
         const queryIndex = url.indexOf("?");
-        if (queryIndex >= 0 && openingBracketIndex > queryIndex) {
+        if (queryIndex >= 0 && openingBracketIndex.index > queryIndex) {
             return false;
         }
         return true;
@@ -2399,6 +2401,7 @@
         urlTemplate = urlTemplate.trim();
         const exactBeginning = urlTemplate[0] === "^";
         const exactEnding = urlTemplate[urlTemplate.length - 1] === "$";
+        const hasLastSlash = /\/\$?$/.test(urlTemplate);
         urlTemplate = urlTemplate
             .replace(/^\^/, "")
             .replace(/\$$/, "")
@@ -2431,7 +2434,9 @@
             result += afterSlash.replace("/", "\\/");
             result += ")";
         }
-        result += exactEnding ? "(\\/?(\\?[^/]*?)?)$" : "(\\/?.*?)$";
+        result += exactEnding
+            ? "(\\/?(\\?[^/]*?)?)$"
+            : `(\\/${hasLastSlash ? "" : "?"}.*?)$`;
         return new RegExp(result, "i");
     }
 
@@ -2565,11 +2570,6 @@
             });
         }
         async getData() {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_GET_DATA
-                );
-            }
             return await this.sendRequest(MessageType.UI_GET_DATA);
         }
         subscribeToChanges(callback) {
@@ -2624,12 +2624,6 @@
             });
         }
         async applyDevDynamicThemeFixes(text) {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_APPLY_DEV_DYNAMIC_THEME_FIXES,
-                    text
-                );
-            }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_DYNAMIC_THEME_FIXES,
                 text
@@ -2641,12 +2635,6 @@
             });
         }
         async applyDevInversionFixes(text) {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_APPLY_DEV_INVERSION_FIXES,
-                    text
-                );
-            }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_INVERSION_FIXES,
                 text
@@ -2658,12 +2646,6 @@
             });
         }
         async applyDevStaticThemes(text) {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_APPLY_DEV_STATIC_THEMES,
-                    text
-                );
-            }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_STATIC_THEMES,
                 text
